EmojiDataUCD class

A class that provides information about the emoji properties of a character

ref: https://www.unicode.org/reports/tr51/

Constructors

EmojiDataUCD(String filename)
Creates a new instance of EmojiDataUCD from a file

Properties

codePoints List<EmojiDataItem>
List of codePoints definitions
getter/setter pairinherited
filename String
UCD file name
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
properties Iterable<String>
Property names present in the file, in first-appearance order.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

find(int target) EmojiDataItem?
Finds a range covering target, or null if no property covers it.
findIn(List<EmojiDataItem> items, int target) EmojiDataItem?
Find codepoint in an arbitrary list of items
inherited
findProp(String property, int target) EmojiDataItem?
Finds the range carrying property that covers target, or null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() Future<void>
Initiates the parsing of the UCD file
sort() → void
Sort the codepoints
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fileName → const String
The filename of the UCD file